#
# spec file for package deadbeef
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without mpg123
%bcond_with mad
%bcond_with restricted
Name:           deadbeef
Version:        0.7.2
Release:        2.1
Summary:        GTK+ audio player
License:        Zlib and GPL-2.0+ and LGPL-2.1+ and BSD-3-Clause
Group:          Productivity/Multimedia/Sound/Players
Url:            http://deadbeef.sourceforge.net/
Source:         http://downloads.sf.net/%{name}/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE deadbeef-fix_ubuntu_unity_desktop.patch i@marguerite.su -- Fix Unity-oriented desktop-file warnings.
Patch0:         %{name}-fix_ubuntu_unity_desktop.patch
# PATCH-FIX-OPENSUSE deadbeef-compiler-warnings.patch olaf@aepfle.de -- Fix compiler warnings.
Patch1:         %{name}-compiler-warnings.patch
# PATCH-FEATURE-UPSTREAM deadbeef-add-appdata.patch -- Add a translateable AppStream metadata file, https://github.com/Alexey-Yakovenko/deadbeef/pull/1705
Patch2:         %{name}-add-appdata.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  libjpeg-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-libs
BuildRequires:  yasm
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(wavpack)
Recommends:     %{name}-lang
%if %{with mpg123}
BuildRequires:  pkgconfig(libmpg123)
%endif
%if %{with mad}
BuildRequires:  pkgconfig(mad)
%endif
%if %{with restricted}
BuildRequires:  libfaad-devel
Requires:       %{name}-plugins-extra = %{version}
%else
Recommends:     %{name}-plugins-extra = %{version}
%endif

%description
DeaDBeeF is an audio player using GTK+. Through use of the ffmpeg
libraries, it supports many formats. It also supports cuesheets,
chiptune formats with subtunes, song-length databases. It can be
extended using plugins (DSP, GUI, output, input, etc.). The GUI looks
similar to Foobar2000.

%lang_package

%if %{with restricted}
%package plugins-extra
Summary:        Extra plugins for DeaDBeeF
License:        Zlib and GPL-2.0+ and LGPL-2.1+ and BSD-3-Clause and Unicode and SUSE-NonFree
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}
Obsoletes:      %{name}-restricted-plugins < %{version}
Provides:       %{name}-restricted-plugins = %{version}

%description plugins-extra
Extra plugins for DeaDBeeF audio player.
%endif

%package devel
Summary:        Development files for %{name}
License:        Zlib
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package provides headers for DeaDBeeF plugins development.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
autoreconf -fi
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"
%configure \
  --disable-static             \
%if %{with restricted}
  --enable-psf                 \
%else
  --disable-psf                \
%endif
  --docdir=%{_docdir}/%{name}/
make %{?_smp_mflags} V=1

%install
%make_install
%suse_update_desktop_file %{name}
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc %{_docdir}/%{name}/
%{_bindir}/%{name}
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/adplug.so*
%{_libdir}/%{name}/alsa.so*
%{_libdir}/%{name}/artwork.so*
%{_libdir}/%{name}/cdda.so*
%{_libdir}/%{name}/ffap.so*
%{_libdir}/%{name}/ffmpeg.so*
%{_libdir}/%{name}/flac.so*
%{_libdir}/%{name}/gme.so*
%{_libdir}/%{name}/hotkeys.so*
%{_libdir}/%{name}/lastfm.so*
%{_libdir}/%{name}/notify.so*
%{_libdir}/%{name}/nullout.so*
%{_libdir}/%{name}/oss.so*
%{_libdir}/%{name}/pulse.so*
%{_libdir}/%{name}/sid.so*
%{_libdir}/%{name}/sndfile.so*
%{_libdir}/%{name}/supereq.so*
%{_libdir}/%{name}/vfs_curl.so*
%{_libdir}/%{name}/vorbis.so*
%{_libdir}/%{name}/vtx.so*
%{_libdir}/%{name}/wavpack.so*
%{_libdir}/%{name}/wma.so*
%{_libdir}/%{name}/dca.so*
%{_libdir}/%{name}/mms.so*
%{_libdir}/%{name}/musepack.so*
%{_libdir}/%{name}/shellexec.so*
%{_libdir}/%{name}/tta.so*
%{_libdir}/%{name}/wildmidi.so*
%{_libdir}/%{name}/converter.so*
%{_libdir}/%{name}/dsp_libsrc.so*
%{_libdir}/%{name}/m3u.so*
%if %{with mpg123}
%{_libdir}/%{name}/mp3.so*
%endif
%{_libdir}/%{name}/vfs_zip.so*
%{_libdir}/%{name}/ddb_dumb.so*
%{_libdir}/%{name}/ddb_mono2stereo.so*
%{_libdir}/%{name}/ddb_shn.so*
%{_libdir}/%{name}/alac.so*
%{_libdir}/%{name}/in_sc68.so*
%{_libdir}/%{name}/data68/
%{_libdir}/%{name}/converter_gtk?.so*
%{_libdir}/%{name}/ddb_gui_GTK?.so*
%{_libdir}/%{name}/pltbrowser_gtk?.so*
%{_libdir}/%{name}/shellexecui_gtk?.so*
%{_libdir}/%{name}/convpresets/
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%files lang -f %{name}.lang
%defattr(-,root,root)

%if %{with restricted}
%files plugins-extra
%defattr(-,root,root)
%{_libdir}/%{name}/aac.so*
%{_libdir}/%{name}/ddb_ao.so*
%if %{with mpg123}
%{_libdir}/%{name}/mp3.so*
%endif
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/

%changelog
* Tue Jun 27 2017 olaf@aepfle.de
- buildconditional for mad and mpg123
* Thu May 11 2017 sor.alexei@meowr.ru
- Enable building with libmpg123 and libmad for newer openSUSE
  releases even outside of Packman.
* Wed Mar 15 2017 olaf@aepfle.de
- List all %%doc files to fix build with rpm 4.13
* Sun Feb  5 2017 mailaender@opensuse.org
- Add deadbeef-add-appdata.patch for
  https://software.opensuse.org/appstore
* Sun Feb  5 2017 jengelh@inai.de
- Update description
* Wed May  4 2016 sor.alexei@meowr.ru
- Update to version 0.7.2:
  * Fix title formatting %%filename%% crash.
  * Fix streaming of aac content in mp4 container.
  * Add https:// support to vfs_curl.
  * Add zh_TW translation to deadbeef.desktop.
  * Fix loading cue sheets without any metadata fields.
  * Fix file close bug in VTX plugin.
  * Fix evaluating nested square brackets syntax in title
    formatting.
  * Improve support for large fields in ID3v2 tags.
  * Fix potential crash bug in artwork plugin.
  * Fix path separator '/' escaping regression in converter.
  * Move ffmpeg plugin to the end of plugin list, to prevent
    conflicts with other input plugins.
  * Add $fix_eol, $hex title formatting.
  * Fix importing [, ] and \n characters from old configuration
    files.
  * Fix "Group by artist/date/title" title formatting.
  * Add enumerating/exposing of all supported file extensions to
    ffmpeg plugin.
  * Fix handling of ':' in file path in vfs_zip plugin.
  * Fix old ffmpeg versions support.
  * Fix wma decoder loudness issue.
  * Fix DCA buffer allocation, to make it more musl-friendly.
  * Add $num implementation to title formatting.
  * Fix --nowplaying-tf behavior when player is stopped.
- Remove deadbeef-0.7.1-fix-osd-notify.patch.
- Rebase deadbeef-fix_ubuntu_unity_desktop.patch.
* Wed Apr  6 2016 sor.alexei@meowr.ru
- Add deadbeef-0.7.1-fix-osd-notify.patch from the upstream commit
  da89020: fix a crash when processing "%%filename%%".
* Tue Mar 15 2016 sor.alexei@meowr.ru
- Update to 0.7.1:
  * Fix GTKUI maximised window layout saving/restoring.
  * Fix GTKUI maximised window column autoresize saving/restoring.
  * Fix artwork plugin version checks.
  * Disable bogus shift-jis detection, which was overriding cp1252.
  * Fix MP3 bitrate calculation regression.
  * Fix wrong padding of formatted time.
  * Fix importing legacy title formatting fields bug.
  * Fix incorrect output format after resuming paused session.
  * Fix $ext title formatting bug.
  * Fix %%tracknumber%% title formatting bug.
  * Fix auto-updating title formatting fields.
  * Fix cache cleaner crash bug.
  * Fix crash when trying to play GYM files.
  * Fix importing legacy playlist grouping config.
  * Fix FLAC metadata field mapping.
  * Fix FLAC metadata track/total and disc/total splitting.
* Mon Feb  1 2016 sor.alexei@meowr.ru
- Update to 0.7.0:
  * converter: Fix bug overwriting the source file with destination.
  * artwork: add cache cleaner, MusicBrainz backend;
    + configurable default picture, numerous bugfixes;
    + performance improvements, more customisation options.
  * playlist browser: improve drag-n-drop;
    + double-click / middle-click on empty area to create new
    playlist;
    + middle-click on playlist to remove it;
    + highlight current playlist, configurable columns;
    + sort columns by clicking their headers;
    + performance optimisations.
  * Various selection properties improvements.
  * Add "Skip to ..." next/prev album/genre/composer actions.
  * More appearance customisation options in GTK+UI.
  * Add center-alignment option to playlist columns.
  * Add 1 and 5 second "Seek forward/backward" actions.
  * Fix random gtkui crash when closing playlist via menu.
  * New title formatting implementation, aiming to be compatible
    with fb2k, replacing the old one.
  * Add grouping to search window.
  * Improve error handling in vfs_curl.
  * Fix volume control via mouse scroll when using Gtk3.
  * Fix unwanted restarting when unpausing streaming tracks of
    known length.
  * sid: Use stereo by default, with an option to force mono;
    fix performance issues.
  * cdda: Improve cddb support, libcdparanoia, multiple CD drives,
    speed selection.
  * gtkui: Add selection focus, such that the found tracks will be
    focused while using the search window.
  * tags: Use cp1252 instead of iso8859-1 everywhere.
  * Fix resuming network streams after losing network connection.
  * Fix cuesheet charset detection crash bug.
  * Rename mpgmad plugin to "mp3".
  * Add libmpg123 support as a 2nd backend to mp3 plugin, as default.
  * mp3: Fix xing header parsing, length calculation issues.
  * Favour album artist over artist in "stop after current album"
    mode.
  * gme: Fix SAP file duration and improved looping handling.
  * sid: Automatic detection of HVSC SongLengths.txt from sid file
    paths.
  * gtkui: Add Tabs widget in Design mode.
  * Add sc68 plugin for playing Atari ST music.
  * Add on-demand initialisation to wild-midi, to speed up player
    init.
  * flac: Fix legacy cuesheet handling.
  * Add writing updated replaygain info to all supported tag
    formats.
  * Fix setting focus on the main window / playlist on startup.
  * Change volume up/down actions to have a step of 1dB instead of
    2dB.
  * Fix bigendian support in the converter.
  * Update DUMB and GME to the newest versions.
  * Fix handling of several formats in sndfile plugin.
  * Add support for ORIGINAL_RELEASE_TIME and ORIGINAL_RELEASE_YEAR
    metadata fields.
  * Add loading plugins from a $DEADBEEF_PLUGIN_DIR directory.
  * Fix a bug which was skipping next track after deleting current
    track.
  * DUMB and GME can now do their own proper infinite looping in
    "Loop single" mode.
  * alac: Fix bits per sample varying from what the MP4 container
    specifies.
  * psf: Fix crash after format probing failure.
  * Search window title will show the number of search results.
  * SRC resampler: Fix very rare buffer overflow crash.
  * mp3: Add LAME preset support.
  * album art: Fix scaling of non-square images.
  * ffmpeg: Update to support new library versions.
  * gtkui: Improve playlist column drag-n-drop.
  * Configuration file is now written with 0600 permissions.
  * Add tracktotal and disctotal support for many tagging formats.
  * Add extended ID3v1 genres.
  * Fix int-float conversion off-by-one precision bug.
  * Fix sorting algorithm u8_strcasecmp stability issue.
  * Fix playlist context menu actions to work on clicked playlist,
    instead of the current one.
- Add plugin licences to the main package.
- Move GME plugin to the main package.
- Rebase deadbeef-fix_ubuntu_unity_desktop.patch.
- Update deadbeef-compiler-warnings.patch.
- Remove workaround_div_by_zero.diff: merged upstream.
* Tue Sep  1 2015 sor.alexei@meowr.ru
- Enable Gtk2 build.
- Move Game Music Emu and AOSDK plugins to deadbeef-plugins-extra
  package: non-commercial restriction makes these plugins non-FOSS.
- Require deadbeef-plugins-extra instead of recommending in PMBS.
* Thu Jun 25 2015 olaf@aepfle.de
- Fix compiler warnings
* Tue Jun  2 2015 sor.alexei@meowr.ru
- Fix build of vfs_zip plugin.
- Rename deadbeef-restricted-plugins to deadbeef-plugins-extra.
- Move locales to deadbeef-lang package.
- Move documentation to a proper directory.
- Do not use _service for downloading the tarball.
- Spec cleanup.
* Sat Nov  8 2014 aloisio@gmx.com
- New upstream version 0.6.2
  - added "Stop playback after current album finished" (Aleksejs Popovs)
  - added ALAC, OPUS, OggFlac encoder presets (Ian Nartowicz)
  - added configure option to build artwork plugin without network support
  - added new widget for muting chiptune voices
  - added support for SHIFT-JIS charset detection/recoding (off by default)
  - fixed "stop after current" bug, which required player restart on every change
  - fixed --gui command line option
  - fixed GUI seeking accuracy bug
  - fixed bug in extended frame flags conversion between ID3v2.3 and ID3v2.4 tag formats
  - fixed crash when loading playlist from command line
  - fixed loading album art (APIC frame) from ID3v2.4 with data length indicator
  - fixed non-utf8 locale support in console
  - fixed support for vorbis files with more than 6 channels
  - fixed playlist count limit bug
  - fixed preserving file permissions after editing ogg files
  - fixed several bugs in PLS playlist format support
  - improved FreeBSD and OSX support
  - improved charset detection in CUE and ID3v1
  - improved album art column rendering/resizing (Christian Boxdörfer)
  - improved the build system and the output build quality
  - improved detection of config changes, to avoid unnecessary config writing
  - improved support for reading APEv2 and ID3v1 tags from large files (>2Gb)
  - updated licensing information in all plugins, to include information about all used libraries
  - aac: added workaround for 7 channel sound playback bug
  - ape: play files with format >= 4.11, improved error handling
  - artwork: many fixes and improvements, including support for non-tagged files
  - dumb: added option to configure internal volume
  - ffmpeg: fixed bitrate calculation
  - ffmpeg: fixed replaygain support
  - flac: fixed/improved many things in tag reading and writing code
  - gme: added support for loading gzipped modules from supported archives (e.g. from zips)
  - gtkui, pltbrowser: better accessibility
  - gtkui: added option to disable seekbar overlay
  - gtkui: added option to display playback state as unicode characters, instead of bitmaps
    (works better on HDPI screens)
  - gtkui: added support for design mode to more widgets (seekbak, volumebar, playback toolbar)
  - gtkui: fixed bug in gtk_drag_check_threshold handler
  - gtkui: numerous fixes in widget layout code
  - gtkui: single/double clicking on album art column will select/play the album/group
    (Christian Boxdörfer)
  - lastfm: added support for scrobbling radio streams (off by default)
  - lastfm: added support for scrobbling tracks shorter than 30 sec (off by default)
  - lastfm: improved support for musicbrainz track id
  - mms: fixed few buffer overflow bugs, improved responsiveness
  - mp3: optimized scanner: less backward seeks during frame syncing
  - shellexec: fixed escaping of single quotes, prevent opening copies of shxui dialogs
  - vfs_zip: huge speed improvements
  - vorbis, oggflac: new tagging code (Ian Nartowicz)
  - improved plugin duplicate checking
  - fixed RIFF WAVE header writing in converter
  - fixed 8bit png crash in album art plugin (Ian Nartowicz)
  - static builds now use -O3 -D_FORTIFY_SOURCE=0 compiler flags
  - fixed few issues with implementation of the Play button
  - improved tag writing in converter
  - fixed issues with "background jobs are running" warning
  - changed all wiki links to point to the new wiki on github
  - improved streamer event handling, to make the GUI more responsive and stable
  - fixed cleaning up downloaded temporary playlist files
  - Fixed skipping bad FLAC__METADATA_TYPE_CUESHEET blocks in FLAC
  - added support for uppercase .CUE extension
  - added "mpga" extension support (mp3)
  - fixed seeking backwards using hotkeys when in the beginning of a track
* Mon Mar  3 2014 dap.darkness@gmail.com
- libffmpeg_oldabi-devel (required to build) was replaced by
  libffmpeg-devel to fix packman's build.
* Sat Feb 22 2014 dap.darkness@gmail.com
- new upsream version 0.6.1
  - don't allow spawning multiple instances of converter
  - added config option to help debug buffering/streaming
  - ffmpeg plugin can now handle dynamic data format changes
  - added support for loading plugins from ~/.local/lib{32|64}/
    /deadbeef, depending on running deadbeef build version
  - removed libstdc++ hacks from C++ plugins
  - paused network streams don't attempt to prebuffer until played
  - unpausing network streams always restarts them
  - prevent loading playlists from archives
    (treat them like folders)
  - hide the "Hotkeys" tab from preferences
    if hotkeys plugin is not available
  - don't build shellexecui if not building shellexec
  - prevent passing non-utf8 filenames to progress dialog
  - don't delete replaygain info from FLACs when writing tags
  - gui layout designer, with a set of widgets to choose from
    (View -> Design mode, then use right click)
  - new API for creating GUI extension plugins
  - visualization support, spectrum analyzer and scope widgets
  - new hotkeys system, which adds local hotkeys,
    and many more actions to choose from
  - playlist browser widget:
    a vertical alternative to playlist tabs
  - album art viewer widget
  - selection properties widget
  - button widget: put custom buttons to main window,
    and assign any actions to them
  - showing seek time in the bar during seeking
  - added worldofspectrum downloader to artwork plugin
    (for AY tunes)
  - native flac cuesheet support
  - added GTK3.6 filechooser filter regression workaround
  - added location field to the metadata tab in track properties
  - new WMA plugin
  - added customizable content-type mapper,
    to associate network streams with plugins
  - subtracks no longer get written to pls and m3u
  - warn a user if he attempts to quit while a job is running
    (e.g. converter)
  - added GTK3 touchpad smooth scrolling support
    (kudos to thesame)
  - added option to always convert 16 bit input signal to 24 bit
  - added OPUS and TAK support in the static build (via ffmpeg)
- switched to _service file.
- post-build-checks were disabled because of
  http://code.google.com/p/ddb/issues/detail?id=1057
- update deadbeef-fix_ubuntu_unity_desktop.patch
* Wed Dec 19 2012 andrea@opensuse.org
- new upsream version 0.5.6
  - wavpack: fixed reload_metadata not clearing old data
  - sndfile: fixed big/little endian byte swap buffer overrun
  - gme: fixed loopcount bugs
  - alsa: fixed race condition bug leading to freezes
  - alac: added new ALAC plugin with proper gapless playback support and other goods
  - aac: lots of bugfixes and improvements, as usual, including half/double
    duration bugfix, and custom metadata fields support, and audiobook chapters
  - cue and m3u parsers can now skip utf8 BOM
  - automatically fill new/edited column title from the selected column type
  - removed the frame widget around playlist to make scroll bar more accessible
    in maximized windows
  - restored old GDK drawing in GTK2 plugin, because cairo produces weird results on
    older GTK2 versions -- that means, tabs and playlist now look correct again
    with gtk2.20 and below
  - gtk3 compiling is now enabled by default, if gtk3 sdk is installed
  - --enable/disable-gtkui configure option is removed, now there are only --enable/disable-gtk2
    and --enable/disable-gtk3
  - added Menu key support
  - always auto-name playlist by folder name when empty, even if the playlist title is non-default
  - insert/delete key support in track properties (Ruslan Khusnullin)
  - fixed Enter and Esc keys in track properties
  - fixed playlist column auto-resizing in maximized window
  - added user-agent configuration for last.fm, vfs_curl, etc
  - added cp936 charset detection support. it breaks cp1251 detection, so it's done as an option
  - - look in the preferences (Joey Zheng)
  - show blank instead of "?" when a metadata field is absent
  - fixed local album cover files search order, it's alphabetical now
  - alsa: added a hack/work-around to prevent releasing sound device when a user switches between tracks
  - m3u: improved handling of relative file pathes
  - converter: fixed handling "/" in filenames; fixed tag-writing to files which have special characters
  - fixed resuming last session in shuffle albums mode
  - fixed several libmms freeze/hang/crash bugs
  - vorbis: update waveformat dynamically, so now it's possible to listen the radios which
    switch between mono and stereo dynamically
  - mp3: fixed samplerate shown in the track properties
  - added work-around for unsupported channel masks to wavpack and sndfile plugins
  - fixed notification cover-art loading for tracks with empty album
* Wed Sep 26 2012 jzheng@suse.com
- update to git commit 8f3b1661fd1372508b35de39ca1cc405f1111c0e
- remove patch files as upstream accepts them
- update deadbeef-fix_ubuntu_unity_desktop.patch
- update spec to include alac
* Sat Sep  8 2012 jzheng@suse.com
- update deadbeef_Fix_CDTEXT.patch to prepare for upstream
* Thu Aug 30 2012 jzheng@suse.com
- update to 0.5.5
- remove deadbeef-0.5.0-fix-return-values.patch and
  deadbeef-0.5.0-fix-strcmp.patch as no need any more.
- refresh deadbeef_FixGB.patch and fix_ubuntu_unity_desktop.patch
  based on now version.
- add deadbeef_gtk_combo_box_entry_new_text.patch
- add deadbeef_Fix_CDTEXT.patch
- add enable-gtk3 option to enable gtk3 interface for openSUSE 12.x
- add new plugin files to file list
* Mon Jan 30 2012 jzheng@suse.com
- let version higher than the one in pacman to avoid some update
  issues.
* Sun Jan 29 2012 i@marguerite.su
- Fix Ubuntu Unity Oriented Desktopfile Warnings. SuSE doesn't need that.
* Sun Jan 29 2012 jzheng@suse.com
- Add hack to support cp936 (GBK, GB18030)
* Sat Jun  4 2011 andrea@opensuse.org
- New upstream version 0.5.1
* Mon May 16 2011 andrea@opensuse.org
- New upstream version 0.5.0
* Mon Mar 14 2011 gber@opensuse.org
- call %%desktop_database_post/un and %%icon_theme_cache_post/un
* Thu Dec  2 2010 gber@opensuse.org
- added deadbeef-0.4.4-fix-undefined-assignments.patch and
  deadbeef-0.4.4-fix-return-value.patch to fix compile warnings
* Wed Dec  1 2010 andrea@opensuse.org
- new upstream version 0.4.4
  - fixed crash in OSS plugin
  - fixed random crashes caused by upgrading to libcurl-7.21.2
  - fixed metadata editing in non-english locales
  - fixed switching playlists using hotkeys with caps/num/xcb
  modifiers
  - made preferences window tabs scrollable
  - fixed dts plugin description
  - fixed 'n' hotkey with numlock
  - improved support for icy (shoutcast) protocol
  - fixed ctrl+j (jump to current track) to work correctly with
  multiple playlists
  - fixed cursor/scroll follows playback to work correctly with
  multiple playlists
  - session resume does not seek anymore after skipping failed track
  - fixed seekbar flickering
  - bundled libmms library to fix freezes after updating to 0.6
  - blank cue tracks (without titles) are not skipped anymore
  - fixed trailing whitespace handling in cuesheets
  - "middle mouse button to delete playlist" is now default behavior
  - fixed few issues with auto-saving playlist configuration
  - fixed playlist redraw after cddb queries
* Fri Jun  4 2010 andrea@opensuse.org
- new upstream version 0.4.1 - bug fix release
* Mon May 24 2010 andrea@opensuse.org
- added deadbeef-0.4.0-fix-critical-warning.patch to make
  brp-checks happy
* Sun May 23 2010 andrea@opensuse.org
- New package
